@@ -7,6 +7,7 @@ extern crate proc_macro;
 mod args;
 mod complex_object;
 mod description;
+mod directive;
 mod r#enum;
 mod input_object;
 mod interface;
@@ -25,7 +26,7 @@ mod validators;
 use darling::{FromDeriveInput, FromMeta};
 use proc_macro::TokenStream;
 use syn::parse_macro_input;
-use syn::{AttributeArgs, DeriveInput, ItemImpl};
+use syn::{AttributeArgs, DeriveInput, ItemFn, ItemImpl};
 
 #[proc_macro_attribute]
 #[allow(non_snake_case)]
@@ -201,3 +202,18 @@ pub fn derive_newtype(input: TokenStream) -> TokenStream {
         Err(err) => err.write_errors().into(),
     }
 }
+
+#[proc_macro_attribute]
+#[allow(non_snake_case)]
+pub fn Directive(args: TokenStream, input: TokenStream) -> TokenStream {
+    let directive_args =
+        match args::Directive::from_list(&parse_macro_input!(args as AttributeArgs)) {
+            Ok(directive_args) => directive_args,
+            Err(err) => return TokenStream::from(err.write_errors()),
+        };
+    let mut item_fn = parse_macro_input!(input as ItemFn);
+    match directive::generate(&directive_args, &mut item_fn) {
+        Ok(expanded) => expanded,
+        Err(err) => err.write_errors().into(),
+    }
+}
